@@ -84,22 +84,14 @@ send_focus_change (GtkWidget *widget,
 {
 	GdkEvent *fevent = gdk_event_new (GDK_FOCUS_CHANGE);
 
-	g_object_ref (widget);
-
-	if (in)
-		GTK_WIDGET_SET_FLAGS (widget, GTK_HAS_FOCUS);
-	else
-		GTK_WIDGET_UNSET_FLAGS (widget, GTK_HAS_FOCUS);
-
 	fevent->focus_change.type = GDK_FOCUS_CHANGE;
-	fevent->focus_change.window = g_object_ref (widget->window);
+	fevent->focus_change.window = gtk_widget_get_window (widget);
 	fevent->focus_change.in = in;
+	if (fevent->focus_change.window)
+		g_object_ref (fevent->focus_change.window);
 
-	gtk_widget_event (widget, fevent);
+	gtk_widget_send_focus_change (widget, fevent);
 
-	g_object_notify (G_OBJECT (widget), "has-focus");
-
-	g_object_unref (widget);
 	gdk_event_free (fevent);
 }
 
@@ -246,10 +238,12 @@ static void
 ev_annotation_window_set_resize_cursor (GtkWidget          *widget,
 					EvAnnotationWindow *window)
 {
-	if (!widget->window)
+	GdkWindow *gdk_window = gtk_widget_get_window (widget);
+
+	if (!gdk_window)
 		return;
 
-	if (GTK_WIDGET_IS_SENSITIVE (widget)) {
+	if (gtk_widget_is_sensitive (widget)) {
 		GdkDisplay *display = gtk_widget_get_display (widget);
 		GdkCursor  *cursor;
 
@@ -257,10 +251,10 @@ ev_annotation_window_set_resize_cursor (GtkWidget          *widget,
 						     widget == window->resize_sw ?
 						     GDK_BOTTOM_LEFT_CORNER :
 						     GDK_BOTTOM_RIGHT_CORNER);
-		gdk_window_set_cursor (widget->window, cursor);
+		gdk_window_set_cursor (gdk_window, cursor);
 		gdk_cursor_unref (cursor);
 	} else {
-		gdk_window_set_cursor (widget->window, NULL);
+		gdk_window_set_cursor (gdk_window, NULL);
 	}
 }
 
@@ -288,7 +282,7 @@ ev_annotation_window_init (EvAnnotationWindow *window)
 	GtkWidget *icon;
 	GtkWidget *swindow;
 
-	GTK_WIDGET_SET_FLAGS (window, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (GTK_WIDGET (window), TRUE);
 
 	vbox = gtk_vbox_new (FALSE, 0);
 
@@ -325,6 +319,7 @@ ev_annotation_window_init (EvAnnotationWindow *window)
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
 	window->text_view = gtk_text_view_new ();
+	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (window->text_view), GTK_WRAP_WORD);
 	g_signal_connect (window->text_view, "button_press_event",
 			  G_CALLBACK (text_view_button_press),
 			  window);
@@ -381,7 +376,7 @@ ev_annotation_window_init (EvAnnotationWindow *window)
 
 	gtk_container_set_border_width (GTK_CONTAINER (window), 2);
 
-	gtk_window_set_accept_focus (GTK_WINDOW (window), FALSE);
+	gtk_window_set_accept_focus (GTK_WINDOW (window), TRUE);
 	gtk_window_set_decorated (GTK_WINDOW (window), FALSE);
 	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (window), TRUE);
 	gtk_window_set_skip_pager_hint (GTK_WINDOW (window), TRUE);
@@ -627,7 +622,7 @@ ev_annotation_window_grab_focus (EvAnnotationWindow *window)
 {
 	g_return_if_fail (EV_IS_ANNOTATION_WINDOW (window));
 
-	if (!GTK_WIDGET_HAS_FOCUS (window->text_view)) {
+	if (!gtk_widget_has_focus (window->text_view)) {
 		gtk_widget_grab_focus (GTK_WIDGET (window));
 		send_focus_change (window->text_view, TRUE);
 	}
@@ -638,7 +633,7 @@ ev_annotation_window_ungrab_focus (EvAnnotationWindow *window)
 {
 	g_return_if_fail (EV_IS_ANNOTATION_WINDOW (window));
 
-	if (GTK_WIDGET_HAS_FOCUS (window->text_view)) {
+	if (gtk_widget_has_focus (window->text_view)) {
 		send_focus_change (window->text_view, FALSE);
 	}
 
